Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(252)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java

Issue 2751583002: 🏡 Show correct BottomSheetContent toolbar when contents swapped (Closed)
Patch Set: Remove duplicate "and" Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/android/java/src/org/chromium/chrome/browser/widget/BottomSheetContentController.java ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java b/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
index 8103d59124a5c6c67f5164ce87acd31e0a3aaca5..674350cc979adffdef45b827102d616a66c8ac18 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/widget/selection/SelectableListLayout.java
@@ -17,6 +17,7 @@ import android.support.v7.widget.RecyclerView.Adapter;
import android.support.v7.widget.RecyclerView.AdapterDataObserver;
import android.support.v7.widget.RecyclerView.ItemAnimator;
import android.support.v7.widget.RecyclerView.OnScrollListener;
+import android.support.v7.widget.Toolbar;
import android.support.v7.widget.Toolbar.OnMenuItemClickListener;
import android.util.AttributeSet;
import android.view.LayoutInflater;
@@ -298,21 +299,13 @@ public class SelectableListLayout<E>
}
/**
* Removes the content view from this view and returns it so that it may be re-attached
* elsewhere.
- * @return The content view, which consists of the {@link RecyclerView} that holds the list of
- * items, the empty view, and the loading view.
+ * @return The toolbar view.
*/
- public View detachContentView() {
- View contentView = findViewById(R.id.list_content);
- assert contentView != null;
- removeView(contentView);
-
- // The background color is typically set on the SelectableListLayout rather than the content
- // view. Set the background color for the content view so that it is not transparent.
- contentView.setBackground(getBackground());
-
- return contentView;
+ public Toolbar detachToolbarView() {
+ removeView(mToolbar);
+ return mToolbar;
}
/**
« no previous file with comments | « chrome/android/java/src/org/chromium/chrome/browser/widget/BottomSheetContentController.java ('k') | no next file » | no next file with comments »
@@ -298,21 +299,13 @@ public class SelectableListLayout<E>
}
/**
- * Removes the content view from this view and returns it so that it may be re-attached
+ * Removes the toolbar view from this view and returns it so that it may be re-attached
* elsewhere.

Powered by Google App Engine
This is Rietveld 408576698